@@ -2,10 +2,10 @@ package Catmandu::Cmd;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0304';
+our $VERSION = '1.0305';
 
 use parent qw(App::Cmd::Command);
-use Catmandu::Util qw(pod_section);
+use Catmandu::Util qw(:is pod_section);
 use Catmandu::Fix;
 use I18N::Langinfo qw(langinfo CODESET);
 use Encode qw(decode);
